@@ -74,8 +74,6 @@ class AccessDMW(DatabaseMiddleware):
                        fetch_fields: List[str] = None,
                        **kwargs) -> Tuple[List[GenericDbType], int]:
         query = model.filter()
-        if "banned" in model._meta.fields:
-            query = query.filter(banned=False)
         if kwargs:
             if "order_by" in kwargs:
                 query = query.order_by(kwargs.pop("order_by"))
@@ -89,6 +87,7 @@ class AccessDMW(DatabaseMiddleware):
         try:
             entities = await query
             query._limit = None
+            query._offset = None
             total = await query.count()
         except FieldError:
             raise InconsistencyError(message="Incorrect filter")
