@@ -75,15 +75,9 @@ class DictRouter(ExtRouter):
         self._router_conf = routes_config
         self.chains = []
         self.versioning = versioning
+        self._parse()
 
-    def apply_routes(self, app: Sanic, **kwargs):
-        """
-        If you want use chaining, please use partial(chain,validation_fnc=...,response_fabric=...)
-        :param **kwargs:
-        :param chaining:
-        :return:
-        """
-
+    def _parse(self):
         for app_route in self._router_conf.get("apps"):
             version_prefix = app_route.get("version_prefix")
             version_prefix = version_prefix if version_prefix else "/api/v"
@@ -111,21 +105,40 @@ class DictRouter(ExtRouter):
                             chain = self.chaining(
                                 protector=protector,
                                 in_struct=in_dto)(target_func)
+
+                        chain = add_openapi_spec(uri=endpoint, method_name=method_name, func=target_func,
+                                                 handler=chain, in_dto=in_dto, out_dto=out_dto)
+
                         methods_confs.append(RouteMethodConf(method_name=method_name,
                                                              protector=protector,
                                                              in_dto=in_dto,
                                                              out_dto=out_dto,
-                                                             handler=target_func
+                                                             handler=target_func,
+                                                             chain=chain,
+                                                             version_prefix=version_prefix,
+                                                             version=version
                                                              ))
-                        chain = add_openapi_spec(uri=endpoint, method_name=method_name, func=target_func,
-                                                 handler=chain, in_dto=in_dto, out_dto=out_dto)
-                        if self.versioning:
-                            app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain,
-                                          version_prefix=version_prefix, version=version)
-                        else:
-                            app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain)
 
-                    route = RouteConf(app_name=app_route.get("app_name"), path=endpoint, methods=methods_confs)
+                    route = RouteConf(app_name=app_route.get("app_name"),
+                                      path=endpoint,
+                                      methods=methods_confs)
                     self.chains.append(route)
 
+    def apply_routes(self, app: Sanic, **kwargs):
+        """
+        If you want use chaining, please use partial(chain,validation_fnc=...,response_fabric=...)
+        :param **kwargs:
+        :param chaining:
+        :return:
+        """
+        for route_conf in self.chains:
+            for method_conf in route_conf.methods:
+                if self.versioning:
+                    app.add_route(uri=route_conf.path, methods={method_conf.method_name.upper()},
+                                  handler=method_conf.chain,
+                                  version_prefix=method_conf.version_prefix, version=method_conf.version)
+                else:
+                    app.add_route(uri=route_conf.path, methods={method_conf.method_name.upper()},
+                                  handler=method_conf.chain)
+
         # warn(f"Can't find dto or handler in imported module, suppressed exception: {e.__str__()}")
