@@ -19,7 +19,7 @@ class Worker(Isolate):
         return self._configured
 
     @inject
-    async def _init_resources(self, app_container=Provide["<container>"]):
+    async def _init_resources(self, app=None, app_container=Provide["<container>"]):
         await app_container.init_resources()
         for service in app_container.app().services.values():
             service.worker = self
